@@ -324,7 +324,9 @@ class Enum(String):
         return super(Enum, self).stringify(value)
 
     def get_schema(self):
-        return {'enum': self._valid_values}
+        schema = super(Enum, self).get_schema()
+        schema['enum'] = self._valid_values
+        return schema
 
 
 class StringPattern(FieldType):
@@ -709,14 +711,14 @@ class DictProxyField(object):
         if getattr(obj, self._fld_name) is None:
             return
         return {self._key_type(k): v
-                for k, v in six.iteritems(getattr(obj, self._fld_name))}
+                for k, v in getattr(obj, self._fld_name).items()}
 
     def __set__(self, obj, val):
         if val is None:
             setattr(obj, self._fld_name, val)
         else:
             setattr(obj, self._fld_name,
-                    {six.text_type(k): v for k, v in six.iteritems(val)})
+                    {six.text_type(k): v for k, v in val.items()})
 
 
 class Set(CompoundFieldType):
@@ -932,7 +934,7 @@ class EnumField(BaseEnumField):
 
     This class allows for anonymous enum types to be
     declared, simply by passing in a list of valid values
-    to its constructor. It is generally preferrable though,
+    to its constructor. It is generally preferable though,
     to create an explicit named enum type by sub-classing
     the BaseEnumField type directly.
     '''
@@ -1264,7 +1266,7 @@ class CoercedDict(CoercedCollectionMixin, dict):
 
     def _coerce_dict(self, d):
         res = {}
-        for key, element in six.iteritems(d):
+        for key, element in d.items():
             res[key] = self._coerce_item(key, element)
         return res
 
